@@ -147,9 +147,12 @@ class BasePlot(QwtPlot):
         return self.AXIS_NAMES.get(axis_name, axis_name)
 
     def read_axes_styles(self, section, options):
-        """Read axes styles from section and options (one option
-        for each axis in the order left,right,bottom,top).
-        skip axis if option is None"""
+        """
+        Read axes styles from section and options (one option
+        for each axis in the order left, right, bottom, top)
+        
+        Skip axis if option is None
+        """
         for prm, option in zip(self.axes_styles, options):
             if option is None:
                 continue
@@ -166,6 +169,17 @@ class BasePlot(QwtPlot):
         axis_id = self.get_axis_id(axis_id)
         self.axes_styles[axis_id].title = text
         self.update_axis_style(axis_id)
+        
+    def get_axis_unit(self, axis_id):
+        """Get axis unit"""
+        axis_id = self.get_axis_id(axis_id)
+        return self.axes_styles[axis_id].unit
+        
+    def set_axis_unit(self, axis_id, text):
+        """Set axis unit"""
+        axis_id = self.get_axis_id(axis_id)
+        self.axes_styles[axis_id].unit = text
+        self.update_axis_style(axis_id)
 
     def get_axis_font(self, axis_id):
         """Get axis font"""
@@ -204,9 +218,15 @@ class BasePlot(QwtPlot):
         ticks_font = style.ticks_font.build_font()
         self.setAxisFont(axis_id, ticks_font)
         
+        if style.title and style.unit:
+            title = "%s (%s)" % (style.title, style.unit)
+        elif style.title:
+            title = style.title
+        else:
+            title = style.unit
         axis_text = self.axisTitle(axis_id)
         axis_text.setFont(title_font)
-        axis_text.setText(style.title)
+        axis_text.setText(title)
         axis_text.setColor(QColor(style.color))
         self.setAxisTitle(axis_id, axis_text)
         self.emit(SIG_PLOT_LABELS_CHANGED, self)
@@ -323,9 +343,10 @@ class BasePlot(QwtPlot):
         else:
             raise RuntimeError(_("Unknown file extension"))
         
-    def get_selected_items(self, item_type=None):
+    def get_selected_items(self, z_sorted=False, item_type=None):
         """Return selected items"""
-        return [item for item in self.get_items(item_type=item_type)
+        return [item for item in
+                self.get_items(item_type=item_type, z_sorted=z_sorted)
                 if item.selected]
             
     def get_max_z(self):
